@@ -2,13 +2,13 @@ package App::PerlXLock;
 use strict;
 use warnings;
 use base 'Exporter';
-our $VERSION = "0.05";
+our $VERSION = "0.07";
 our @EXPORT  = qw(main_loop);
 use Inline C => Config => LIBS => '-lX11';
 use Inline
   C       => "DATA",
   NAME    => "App::PerlXLock",
-  VERSION => '0.05',
+  VERSION => '0.07',
   INC     => '/usr/include';
 
 END {
@@ -144,6 +144,8 @@ int open_lock(SV *disp_ref, int screen){
     screen = XDefaultScreen(display);
     root = XRootWindow(display,screen);
     window = XCreateSimpleWindow(display, root, 0, 0, DisplayWidth(display,screen), DisplayHeight(display,screen), 1, BlackPixel(display, screen), BlackPixel(display, screen));
+    attr.override_redirect = 1;
+    XChangeWindowAttributes(display, window, CWOverrideRedirect, &attr);
 
     status = XMapRaised(display, window);
     XRaiseWindow(display, window);
